==> nextcloud-26.0.11p1.tgz: nextcloud/apps/password_policy/l10n/zh_HK.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "密碼已過期，請使用忘記密碼的方法來重設",
    "Password must not have been used recently before." : "密碼不可以是近期使用過的。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "密碼出現在 1，000，000 個常用密碼列表內，請設定獨一無二的密碼。",
    "Password is present in compromised password list. Please choose a different password." : "密碼出現在洩露的密碼清單中。請選擇其它密碼。",
    "Password needs to be at least %s characters long." : "密碼需長於 %s 個字母",
    "Password needs to contain at least one numeric character." : "密碼需要包含至少一個數字。",
    "Password needs to contain at least one special character." : "密碼應包含一個特殊符號。",
    "Password needs to contain at least one lower and one upper case character." : "密碼應包含最少一個大寫與一個小寫。",
    "Password policy" : "密碼規範",
    "Allows admins to configure a password policy" : "允許管理員設定密碼策略",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "允許管理員定義密碼的某些條件，例如強制最小長度",
    "Minimum password length" : "密碼最小長度",
    "User password history" : "用戶密碼歷史記錄",
    "Number of days until user password expires" : "距離密碼到期天數",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "封鎖用戶賬戶前的登入嘗試次數（0 為沒有限制）",
    "Forbid common passwords" : "禁止常用密碼",
    "Enforce upper and lower case characters" : "一定要各用一個大寫與小寫",
    "Enforce numeric characters" : "一定要用數字",
    "Enforce special characters" : "一定要用特殊符號",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "將密碼送至 haveibeenpwned.com 以檢查該組密碼是否存在於外洩的資料集中",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "此項檢查僅使用用戶輸入的密碼之前五個字母，將前五個字母雜湊後傳送到 haveibeenpwned.com 的API以獲得所有由這五個字母開頭之密碼雜湊值清單，而此清單將被下載回 Nextcloud 進行完整比對：亦即 haveibeenpwned.com 只會獲得密碼前五字元的雜湊值，而非完整密碼。",
    "Unknown error" : "錯誤不詳",
    "Minimal length has to be a non negative number" : "最小長度必須為正數",
    "History size has to be a non negative number" : "歷史記錄大小必須為正數",
    "Expiration days have to be a non negative number" : "到期天數必須為正數",
    "Maximum login attempts have to be a non negative number" : "最大登錄嘗試次數必須為正數",
    "Settings saved" : "設定已保存",
    "Error while saving settings" : "儲存設定時發生錯誤",
    "Saved" : "已保存",
    "Error while saving" : "儲存時發生錯誤"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/password_policy/l10n/zh_HK.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "密碼已過期，請使用忘記密碼的方法來重設",
    "Password must not have been used recently before." : "密碼不可以是近期使用過的。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "密碼出現在 1，000，000 個常用密碼列表內，請設定獨一無二的密碼。",
    "Password is present in compromised password list. Please choose a different password." : "密碼出現在洩露的密碼清單中。請選擇其它密碼。",
    "Password needs to be at least %s characters long." : "密碼需長於 %s 個字母",
    "Password needs to contain at least one numeric character." : "密碼需要包含至少一個數字。",
    "Password needs to contain at least one special character." : "密碼應包含一個特殊符號。",
    "Password needs to contain at least one lower and one upper case character." : "密碼應包含最少一個大寫與一個小寫。",
    "Password policy" : "密碼規範",
    "Allows admins to configure a password policy" : "允許管理員設定密碼策略",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "允許管理員定義密碼的某些條件，例如強制最小長度",
    "Minimum password length" : "密碼最小長度",
    "User password history" : "用戶密碼歷史記錄",
    "Number of days until user password expires" : "距離密碼到期天數",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "登錄嘗試次數達到設定值後，用戶帳戶將被停用，需要手動啟用。（設為 0 表示無限制）",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "請注意，此選項旨在保護遭受攻擊的帳戶。已停用的帳戶必須由管理員人手重新啟用。嘗試猜測帳戶密碼的攻擊者的 IP 地址將由暴力攻擊保護機制封鎖，與此設定無關。",
    "Forbid common passwords" : "禁止常用密碼",
    "Enforce upper and lower case characters" : "一定要各用一個大寫與小寫",
    "Enforce numeric characters" : "一定要用數字",
    "Enforce special characters" : "一定要用特殊符號",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "將密碼送至 haveibeenpwned.com 以檢查該組密碼是否存在於外洩的資料集中",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "此項檢查僅使用用戶輸入的密碼之前五個字母，將前五個字母雜湊後傳送到 haveibeenpwned.com 的API以獲得所有由這五個字母開頭之密碼雜湊值清單，而此清單將被下載回 Nextcloud 進行完整比對：亦即 haveibeenpwned.com 只會獲得密碼前五字元的雜湊值，而非完整密碼。",
    "Unknown error" : "錯誤不詳",
    "Minimal length has to be a non negative number" : "最小長度必須為正數",
    "History size has to be a non negative number" : "歷史記錄大小必須為正數",
    "Expiration days have to be a non negative number" : "到期天數必須為正數",
    "Maximum login attempts have to be a non negative number" : "最大登錄嘗試次數必須為正數",
    "Settings saved" : "設定已保存",
    "Error while saving settings" : "儲存設定時發生錯誤",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "請注意，此選項旨在保護遭受攻擊的帳戶。已停用的帳戶必須由管理員人手重新啟用。嘗試猜測帳戶密碼的攻擊者的 IP 地址將由暴力攻擊保護機制封鎖，與此設定無關。"
},
"nplurals=1; plural=0;");
